==> rio-0.0.37.tar.gz: rio-0.0.37/docs/src/data/mentions.js <==
// @ts-check

/** @satisfies {import('@site/src/components/MentionsSection/index').MentionCardProps[]} */
const MENTIONS = [
  {
    tweetUrl: 'https://twitter.com/jaijams/status/1716815864975270005',
    username: 'jaijams',
    quote: (
      <>
        I have been using the Rio terminal (https://raphamorim.io/rio/) for 6
        months. OMG! Rio is my No.1 terminal ♥️ and is super fast 🚀 . Love
        using it daily 🎉
      </>
    ),
  },
  {
    tweetUrl: 'https://twitter.com/mcsmonte/status/1660949303089586177',
    username: 'mcsmonte',
    quote: (
      <>
        This week I'm testing rio, a rust based terminal and I need to say: It's
        amazing! either still beta, could full fill all need working heavily
        with git/docker/spring/npm , I really recommend to get a try and Kudos
        to @raphamorims for fantastic job
      </>
    ),
  },
  {
    tweetUrl: 'https://twitter.com/moeyua13/status/1665983183526195200',
    username: 'moeyua13',
    quote: <>I really love this terminal</>,
  },
  {
    tweetUrl: 'https://twitter.com/peterlazar1993/status/1689965895408402432',
    username: 'peterlazar1993',
    quote: <>I've been dailydriving Rio, it's 🔥</>,
  },
  {
    tweetUrl: 'https://twitter.com/EduRonqui/status/1717288090820055297',
    username: 'EduRonqui',
    quote: (
      <>
        It’s a tiny one but this release features my first ever contribution to
        an open source project and it feels so nice to give back to this amazing
        project that has become my main terminal.
      </>
    ),
  },
  {
    tweetUrl: 'https://twitter.com/EduRonqui/status/1730619921632022997',
    username: 'ferfabricio',
    quote: (
      <>
        Eu comecei a usar o Rio term faz uns dias e ta sendo uma experiência muito bacana! parabéns @raphamorims
      </>
    ),
  },
];

export default MENTIONS;

==> rio-0.1.12.tar.gz: rio-0.1.12/docs/src/data/mentions.js <==
// @ts-check

/** @satisfies {import('@site/src/components/MentionsSection/index').MentionCardProps[]} */
const MENTIONS = [
  {
    tweetUrl: 'https://twitter.com/jaijams/status/1716815864975270005',
    username: 'jaijams',
    quote: (
      <>
        I have been using the Rio terminal (https://raphamorim.io/rio/) for 6
        months. OMG! Rio is my No.1 terminal ♥️ and is super fast 🚀 . Love
        using it daily 🎉
      </>
    ),
  },
  {
    tweetUrl: 'https://twitter.com/mcsmonte/status/1660949303089586177',
    username: 'mcsmonte',
    quote: (
      <>
        This week I'm testing rio, a rust based terminal and I need to say: It's
        amazing! either still beta, could full fill all need working heavily
        with git/docker/spring/npm , I really recommend to get a try and Kudos
        to @raphamorims for fantastic job
      </>
    ),
  },
  {
    tweetUrl: 'https://twitter.com/moeyua13/status/1665983183526195200',
    username: 'moeyua13',
    quote: <>I really love this terminal</>,
  },
  {
    tweetUrl: 'https://twitter.com/peterlazar1993/status/1689965895408402432',
    username: 'peterlazar1993',
    quote: <>I've been dailydriving Rio, it's 🔥</>,
  },
  {
    tweetUrl: 'https://twitter.com/EduRonqui/status/1717288090820055297',
    username: 'EduRonqui',
    quote: (
      <>
        It’s a tiny one but this release features my first ever contribution to
        an open source project and it feels so nice to give back to this amazing
        project that has become my main terminal.
      </>
    ),
  },
  {
    tweetUrl: 'https://twitter.com/EduRonqui/status/1730619921632022997',
    username: 'ferfabricio',
    quote: (
      <>
        Eu comecei a usar o Rio term faz uns dias e ta sendo uma experiência
        muito bacana! parabéns @raphamorims
      </>
    ),
  },
];

export default MENTIONS;
